pub fn decode_verified_program(
bytes: &[u8],
limits: &ProgramDecodeLimits,
) -> Result<Program<Verified>, ProgramLoadError>Expand description
Decodes and verifies a whole program in one boundary operation.
pub fn decode_verified_program(
bytes: &[u8],
limits: &ProgramDecodeLimits,
) -> Result<Program<Verified>, ProgramLoadError>Decodes and verifies a whole program in one boundary operation.