Module

Struct Module 

pub struct Module<State = Unverified> { /* private fields */ }
Explicit constant pool, function table, and entry function, with typestate.

Implementations

Source

impl<State> Module<State>

pub fn constants(&self) -> &[Constant]

pub fn functions(&self) -> &[Function]

pub const fn entry(&self) -> FunctionId

Source

impl Module<Unverified>

pub fn new( constants: Vec<Constant>, functions: Vec<Function>, entry: FunctionId, ) -> Self

pub fn verify(self) -> Result<Module<Verified>, VerifyError>

Consumes untrusted structure and is the only route to Module<Verified>.

Errors

Returns the first structural violation found (bounds, references, CFG, handlers, or definite initialization).

Source

impl Module<Verified>

pub fn certificate(&self, function: FunctionId) -> Option<&Certificate>

pub fn verification_bytes(&self) -> usize

Heap bytes retained by this module’s verification certificates.

pub fn encode(&self) -> Vec<u8>

Emits one deterministic canonical representation.